PyXMake Developer Guide: PyXMake.VTL.stm_make.abq_mcodac Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Attributes | Protected Member Functions | Static Protected Attributes | List of all members
PyXMake.VTL.stm_make.abq_mcodac Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.abq_mcodac:

## Public Attributes
list | copyfiles = ["standardU.dll","explicitU-D.dll"]
str | libs = "mcd_corex64"
list | includes
| base_path
| libpaths = os.path.join(self.base_path,"lib",Utility.GetPlatform(),Utility.GetArchitecture())
Public Attributes inherited from PyXMake.VTL.stm_make.pyx_custom
int | verbose = 2
str | source_path = ''
str | source_file = 'mcd_astandard'
str | output_file_path = ''
str | base_path = ''
| scratch_path = os.getcwd()
| libs = None
| includes = None
| libpaths = None
str | msvsc = "vs2015"
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Protected Member Functions
| _create_command (self)
Protected Member Functions inherited from PyXMake.VTL.stm_make.pyx_custom
| _run_command (self, command)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _perform_post_actions (self)

## Static Protected Attributes
str | _PACKAGE_NAME = 'mcd_abaqus'
int | _MAKE_OPT = 6
Static Protected Attributes inherited from PyXMake.VTL.stm_make.pyx_custom
str | _PACKAGE_NAME = ''
list | _INPUT_FILES = []

## Additional Inherited Members
Public Member Functions inherited from PyXMake.VTL.stm_make.pyx_custom
| initialize_options (self)
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)
Static Public Attributes inherited from PyXMake.VTL.stm_make.pyx_custom
str | description = "Runs an user-defined build process utilizing the PyXMake build environment."
list | user_options
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()

## Detailed Description

    Runs the build process of MCODAC for ABAQUS.

Definition at line 903 of file stm_make.py.

## Member Function Documentation

## ◆ _create_command()

PyXMake.VTL.stm_make.abq_mcodac._create_command | ( |  | self | ) |
| protected

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 911 of file stm_make.py.

## Member Data Documentation

## ◆ _MAKE_OPT

PyXMake.VTL.stm_make.abq_mcodac._MAKE_OPT = 6
| staticprotected

Definition at line 909 of file stm_make.py.

## ◆ _PACKAGE_NAME

str PyXMake.VTL.stm_make.abq_mcodac._PACKAGE_NAME = 'mcd_abaqus'
| staticprotected

Definition at line 908 of file stm_make.py.

## ◆ base_path

PyXMake.VTL.stm_make.abq_mcodac.base_path

Definition at line 924 of file stm_make.py.

## ◆ copyfiles

list PyXMake.VTL.stm_make.abq_mcodac.copyfiles = ["standardU.dll","explicitU-D.dll"]

Definition at line 920 of file stm_make.py.

## ◆ includes

list PyXMake.VTL.stm_make.abq_mcodac.includes

Initial value:
= [os.path.join(self.base_path,"include",Utility.GetPlatform(),Utility.GetArchitecture(), x)
for x in VTL.GetIncludeDirectory(self.base_path, 0, 4, Utility.GetArchitecture())]

Definition at line 922 of file stm_make.py.

## ◆ libpaths

PyXMake.VTL.stm_make.abq_mcodac.libpaths = os.path.join(self.base_path,"lib",Utility.GetPlatform(),Utility.GetArchitecture())

Definition at line 925 of file stm_make.py.

## ◆ libs

str PyXMake.VTL.stm_make.abq_mcodac.libs = "mcd_corex64"

Definition at line 921 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py